@@ -1,9 +1,8 @@
-import os
 from setuptools import setup
 
 setup(
     name='lintest',
-    version='1.7.2',
+    version='1.7.4',
     author='Wang Lin',
     author_email='think_wl@163.com',
     packages=['lintest'],
@@ -15,6 +14,7 @@ setup(
         "setuptools",
         "urllib3",
         "PyMySQL",
+        "jsoncomparison",
         "chromedriver_autoinstaller"
     ]
 )
